@@ -166,7 +166,6 @@ class P100():
 				"device_on": True
 			},
 			"requestTimeMils": int(round(time.time() * 1000)),
-			# "terminalUUID": "1C-3B-F3-A5-71-E5"
 		}
 
 		headers = {
@@ -198,7 +197,6 @@ class P100():
 				"device_on": False
 			},
 			"requestTimeMils": int(round(time.time() * 1000)),
-			# "terminalUUID": "1C-3B-F3-A5-71-E5"
 		}
 
 		headers = {
@@ -223,7 +221,7 @@ class P100():
 			errorMessage = self.errorCodes[str(errorCode)]
 
 	def getDeviceInfo(self):
-		URL = f"http://192.168.0.157/app?token={self.token}"
+		URL = f"http://{self.ipAddress}/app?token={self.token}"
 		Payload = {
 			"method": "get_device_info",
 			"requestTimeMils": int(round(time.time() * 1000)),
